pyparsing.pyparsing.Regex.compiledREtype

Package pyparsing :: Module pyparsing :: Class Regex :: Class compiledREtype |
[frames] | no frames]

# Class compiledREtype

    object --+
             |
            pyparsing.pyparsing.Regex.compiledREtype

Compiled regular expression objects

Instance Methods
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`